@@ -567,6 +567,23 @@ class Base(Controller):
         from ..ext.firelit import create_viz
         create_viz(args.images, args.labels, args.adapted)
 
+    @ex(
+        help="Download file from Google Drive",
+        arguments=[
+            (["file_id"], {
+                "help" : "The file id of the file to download",
+                "action" : "store"
+            }),
+            (["destination"], {
+                "help": "The destination to download the file to",
+                "action" : "store"
+            })
+        ]
+    )
+    def gdrive(self):
+        from ..ext.gdrive_dl import download_file_from_google_drive
+        download_file_from_google_drive(self.app.pargs.file_id, self.app.pargs.destination)
+
 
     @ex(
         help='Operations with config.',
